{#
gopher/layout.html
~~~~~~~~~~~~~~~~~~~~~~~~~~

Master layout template for Sphinx themes.

:copyright: tell-k <ffk2005@gmail.com>
:license: MIT License
#}
<!DOCTYPE html>
<html>
  <head>
    {%- block htmltitle %}
    <title>{{ title|striptags|e }}{{ titlesuffix }}</title>
    {%- endblock %}
    <meta charset='utf-8'>
    <link rel="stylesheet" href="{{ pathto('_static/pygments.css', 1) }}" type="text/css" />
    {%- for cssfile in css_files %}
    <link rel="stylesheet" href="{{ pathto(cssfile, 1) }}" type="text/css" />
    {%- endfor %}
    {%- for scriptfile in script_files %}
      {%- if scriptfile not in ('_static/doctools.js') %}
      <script type="text/javascript" src="{{ pathto(scriptfile, 1) }}"></script>
      {%- endif %}
    {%- endfor %}
  </head>
  <body style='display: none'>
    {% block body %}{% endblock %}
  <div id="help">
      Use the left and right arrow keys or click the left and right
      edges of the page to navigate between slides.<br>
      (Press 'H' or navigate to hide this message.)
  </div>
  </body>
  <script type="text/javascript" src="{{ pathto("_static/js/initialize.js", 1) }}"></script>
  <script type="text/javascript" src="{{ pathto("_static/js/slides.js", 1) }}"></script>
</html>
